#[non_exhaustive]pub struct AssociateQueueEmailAddressesInputBuilder { /* private fields */ }Expand description
A builder for AssociateQueueEmailAddressesInput.
Implementations
Sourceimpl AssociateQueueEmailAddressesInputBuilder
impl AssociateQueueEmailAddressesInputBuilder
Sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
This field is required.Sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn get_instance_id(&self) -> &Option<String>
pub fn get_instance_id(&self) -> &Option<String>
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn queue_id(self, input: impl Into<String>) -> Self
pub fn queue_id(self, input: impl Into<String>) -> Self
The identifier for the queue.
This field is required.Sourcepub fn set_queue_id(self, input: Option<String>) -> Self
pub fn set_queue_id(self, input: Option<String>) -> Self
The identifier for the queue.
Sourcepub fn get_queue_id(&self) -> &Option<String>
pub fn get_queue_id(&self) -> &Option<String>
The identifier for the queue.
Sourcepub fn email_addresses_config(self, input: EmailAddressConfig) -> Self
pub fn email_addresses_config(self, input: EmailAddressConfig) -> Self
Appends an item to email_addresses_config.
To override the contents of this collection use set_email_addresses_config.
Configuration list containing the email addresses to associate with the queue. Each configuration specifies an email address ID that should be linked to this queue for routing purposes.
Sourcepub fn set_email_addresses_config(
self,
input: Option<Vec<EmailAddressConfig>>,
) -> Self
pub fn set_email_addresses_config( self, input: Option<Vec<EmailAddressConfig>>, ) -> Self
Configuration list containing the email addresses to associate with the queue. Each configuration specifies an email address ID that should be linked to this queue for routing purposes.
Sourcepub fn get_email_addresses_config(&self) -> &Option<Vec<EmailAddressConfig>>
pub fn get_email_addresses_config(&self) -> &Option<Vec<EmailAddressConfig>>
Configuration list containing the email addresses to associate with the queue. Each configuration specifies an email address ID that should be linked to this queue for routing purposes.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn build(self) -> Result<AssociateQueueEmailAddressesInput, BuildError>
pub fn build(self) -> Result<AssociateQueueEmailAddressesInput, BuildError>
Consumes the builder and constructs a AssociateQueueEmailAddressesInput.
Sourceimpl AssociateQueueEmailAddressesInputBuilder
impl AssociateQueueEmailAddressesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<AssociateQueueEmailAddressesOutput, SdkError<AssociateQueueEmailAddressesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<AssociateQueueEmailAddressesOutput, SdkError<AssociateQueueEmailAddressesError, HttpResponse>>
Sends a request with this input using the given client.