#[non_exhaustive]pub enum AssociateQueueEmailAddressesError {
AccessDeniedException(AccessDeniedException),
InternalServiceException(InternalServiceException),
InvalidParameterException(InvalidParameterException),
InvalidRequestException(InvalidRequestException),
LimitExceededException(LimitExceededException),
ResourceNotFoundException(ResourceNotFoundException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the AssociateQueueEmailAddressesError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
You do not have sufficient permissions to perform this action.
InternalServiceException(InternalServiceException)
Request processing failed because of an error or failure with the service.
InvalidParameterException(InvalidParameterException)
One or more of the specified parameters are not valid.
InvalidRequestException(InvalidRequestException)
The request is not valid.
LimitExceededException(LimitExceededException)
The allowed limit for the resource has been exceeded.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource was not found.
ThrottlingException(ThrottlingException)
The throttling limit has been exceeded.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl AssociateQueueEmailAddressesError
impl AssociateQueueEmailAddressesError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the AssociateQueueEmailAddressesError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the AssociateQueueEmailAddressesError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::AccessDeniedException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::InternalServiceException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::InvalidParameterException.
Sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::InvalidRequestException.
Sourcepub fn is_limit_exceeded_exception(&self) -> bool
pub fn is_limit_exceeded_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::LimitExceededException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::ResourceNotFoundException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is AssociateQueueEmailAddressesError::ThrottlingException.