#[non_exhaustive]pub struct CreateAttachedFileOutput {
pub file_arn: Option<String>,
pub file_id: Option<String>,
pub creation_time: Option<String>,
pub file_status: Option<FileStatusType>,
/* private fields */
}Expand description
Response from CreateAttachedFile API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_arn: Option<String>The unique identifier of the attached file resource (ARN).
file_id: Option<String>The unique identifier of the attached file resource.
creation_time: Option<String>The time of Creation of the file resource as an ISO timestamp. It's specified in ISO 8601 format: yyyy-MM-ddThh:mm:ss.SSSZ. For example, 2024-05-03T02:41:28.172Z.
file_status: Option<FileStatusType>The current status of the attached file. Valid values: PROCESSING | APPROVED | REJECTED | FAILED.
Implementations
Sourceimpl CreateAttachedFileOutput
impl CreateAttachedFileOutput
Sourcepub fn file_arn(&self) -> Option<&str>
pub fn file_arn(&self) -> Option<&str>
The unique identifier of the attached file resource (ARN).
Sourcepub fn creation_time(&self) -> Option<&str>
pub fn creation_time(&self) -> Option<&str>
The time of Creation of the file resource as an ISO timestamp. It's specified in ISO 8601 format: yyyy-MM-ddThh:mm:ss.SSSZ. For example, 2024-05-03T02:41:28.172Z.
Sourcepub fn file_status(&self) -> Option<&FileStatusType>
pub fn file_status(&self) -> Option<&FileStatusType>
The current status of the attached file. Valid values: PROCESSING | APPROVED | REJECTED | FAILED.
Sourceimpl CreateAttachedFileOutput
impl CreateAttachedFileOutput
Sourcepub fn builder() -> CreateAttachedFileOutputBuilder
pub fn builder() -> CreateAttachedFileOutputBuilder
Creates a new builder-style object to manufacture CreateAttachedFileOutput.