pub struct CreateAuthCodeFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateAuthCode.
Creates an authorization code for the specified Connect Customer instance. The authorization code can be used to establish a session with scoped permissions defined by the specified scope parameters.
Implementations
Sourceimpl CreateAuthCodeFluentBuilder
impl CreateAuthCodeFluentBuilder
Sourcepub fn as_input(&self) -> &CreateAuthCodeInputBuilder
pub fn as_input(&self) -> &CreateAuthCodeInputBuilder
Access the CreateAuthCode as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateAuthCodeOutput, SdkError<CreateAuthCodeError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateAuthCodeOutput, SdkError<CreateAuthCodeError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateAuthCodeOutput, CreateAuthCodeError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateAuthCodeOutput, CreateAuthCodeError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn get_instance_id(&self) -> &Option<String>
pub fn get_instance_id(&self) -> &Option<String>
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn scope(self, input: AuthScope) -> Self
pub fn scope(self, input: AuthScope) -> Self
The scope for the authorization code. Defines the permissions and access boundaries for the session.
Sourcepub fn set_scope(self, input: Option<AuthScope>) -> Self
pub fn set_scope(self, input: Option<AuthScope>) -> Self
The scope for the authorization code. Defines the permissions and access boundaries for the session.
Sourcepub fn get_scope(&self) -> &Option<AuthScope>
pub fn get_scope(&self) -> &Option<AuthScope>
The scope for the authorization code. Defines the permissions and access boundaries for the session.
Sourcepub fn max_session_duration_minutes(self, input: i32) -> Self
pub fn max_session_duration_minutes(self, input: i32) -> Self
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn set_max_session_duration_minutes(self, input: Option<i32>) -> Self
pub fn set_max_session_duration_minutes(self, input: Option<i32>) -> Self
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn get_max_session_duration_minutes(&self) -> &Option<i32>
pub fn get_max_session_duration_minutes(&self) -> &Option<i32>
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn session_inactivity_duration_minutes(self, input: i32) -> Self
pub fn session_inactivity_duration_minutes(self, input: i32) -> Self
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
Sourcepub fn set_session_inactivity_duration_minutes(self, input: Option<i32>) -> Self
pub fn set_session_inactivity_duration_minutes(self, input: Option<i32>) -> Self
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
Sourcepub fn get_session_inactivity_duration_minutes(&self) -> &Option<i32>
pub fn get_session_inactivity_duration_minutes(&self) -> &Option<i32>
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).