#[non_exhaustive]pub struct CreateAuthCodeInputBuilder { /* private fields */ }Expand description
A builder for CreateAuthCodeInput.
Implementations
Sourceimpl CreateAuthCodeInputBuilder
impl CreateAuthCodeInputBuilder
Sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
This field is required.Sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn get_instance_id(&self) -> &Option<String>
pub fn get_instance_id(&self) -> &Option<String>
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn scope(self, input: AuthScope) -> Self
pub fn scope(self, input: AuthScope) -> Self
The scope for the authorization code. Defines the permissions and access boundaries for the session.
This field is required.Sourcepub fn set_scope(self, input: Option<AuthScope>) -> Self
pub fn set_scope(self, input: Option<AuthScope>) -> Self
The scope for the authorization code. Defines the permissions and access boundaries for the session.
Sourcepub fn get_scope(&self) -> &Option<AuthScope>
pub fn get_scope(&self) -> &Option<AuthScope>
The scope for the authorization code. Defines the permissions and access boundaries for the session.
Sourcepub fn max_session_duration_minutes(self, input: i32) -> Self
pub fn max_session_duration_minutes(self, input: i32) -> Self
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn set_max_session_duration_minutes(self, input: Option<i32>) -> Self
pub fn set_max_session_duration_minutes(self, input: Option<i32>) -> Self
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn get_max_session_duration_minutes(&self) -> &Option<i32>
pub fn get_max_session_duration_minutes(&self) -> &Option<i32>
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
Sourcepub fn session_inactivity_duration_minutes(self, input: i32) -> Self
pub fn session_inactivity_duration_minutes(self, input: i32) -> Self
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
This field is required.Sourcepub fn set_session_inactivity_duration_minutes(self, input: Option<i32>) -> Self
pub fn set_session_inactivity_duration_minutes(self, input: Option<i32>) -> Self
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
Sourcepub fn get_session_inactivity_duration_minutes(&self) -> &Option<i32>
pub fn get_session_inactivity_duration_minutes(&self) -> &Option<i32>
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
Sourcepub fn build(self) -> Result<CreateAuthCodeInput, BuildError>
pub fn build(self) -> Result<CreateAuthCodeInput, BuildError>
Consumes the builder and constructs a CreateAuthCodeInput.
Sourceimpl CreateAuthCodeInputBuilder
impl CreateAuthCodeInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAuthCodeOutput, SdkError<CreateAuthCodeError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAuthCodeOutput, SdkError<CreateAuthCodeError, HttpResponse>>
Sends a request with this input using the given client.