#[non_exhaustive]pub struct CreateAuthCodeOutputBuilder { /* private fields */ }Expand description
A builder for CreateAuthCodeOutput.
Implementations
Sourceimpl CreateAuthCodeOutputBuilder
impl CreateAuthCodeOutputBuilder
Sourcepub fn auth_code(self, input: impl Into<String>) -> Self
pub fn auth_code(self, input: impl Into<String>) -> Self
The authorization code to use for establishing a session.
Sourcepub fn set_auth_code(self, input: Option<String>) -> Self
pub fn set_auth_code(self, input: Option<String>) -> Self
The authorization code to use for establishing a session.
Sourcepub fn get_auth_code(&self) -> &Option<String>
pub fn get_auth_code(&self) -> &Option<String>
The authorization code to use for establishing a session.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The identifier of the session created with the authorization code.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The identifier of the session created with the authorization code.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The identifier of the session created with the authorization code.
Sourcepub fn entity_type(self, input: AuthCodeEntityType) -> Self
pub fn entity_type(self, input: AuthCodeEntityType) -> Self
The type of entity associated with the authorization code.
Sourcepub fn set_entity_type(self, input: Option<AuthCodeEntityType>) -> Self
pub fn set_entity_type(self, input: Option<AuthCodeEntityType>) -> Self
The type of entity associated with the authorization code.
Sourcepub fn get_entity_type(&self) -> &Option<AuthCodeEntityType>
pub fn get_entity_type(&self) -> &Option<AuthCodeEntityType>
The type of entity associated with the authorization code.
Sourcepub fn entity_id(self, input: impl Into<String>) -> Self
pub fn entity_id(self, input: impl Into<String>) -> Self
The identifier of the entity associated with the authorization code.
Sourcepub fn set_entity_id(self, input: Option<String>) -> Self
pub fn set_entity_id(self, input: Option<String>) -> Self
The identifier of the entity associated with the authorization code.
Sourcepub fn get_entity_id(&self) -> &Option<String>
pub fn get_entity_id(&self) -> &Option<String>
The identifier of the entity associated with the authorization code.
Sourcepub fn build(self) -> CreateAuthCodeOutput
pub fn build(self) -> CreateAuthCodeOutput
Consumes the builder and constructs a CreateAuthCodeOutput.