#[non_exhaustive]pub struct CreateAuthCodeOutput {
pub auth_code: Option<String>,
pub session_id: Option<String>,
pub entity_type: Option<AuthCodeEntityType>,
pub entity_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auth_code: Option<String>The authorization code to use for establishing a session.
session_id: Option<String>The identifier of the session created with the authorization code.
entity_type: Option<AuthCodeEntityType>The type of entity associated with the authorization code.
entity_id: Option<String>The identifier of the entity associated with the authorization code.
Implementations
Sourceimpl CreateAuthCodeOutput
impl CreateAuthCodeOutput
Sourcepub fn auth_code(&self) -> Option<&str>
pub fn auth_code(&self) -> Option<&str>
The authorization code to use for establishing a session.
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
The identifier of the session created with the authorization code.
Sourcepub fn entity_type(&self) -> Option<&AuthCodeEntityType>
pub fn entity_type(&self) -> Option<&AuthCodeEntityType>
The type of entity associated with the authorization code.
Sourceimpl CreateAuthCodeOutput
impl CreateAuthCodeOutput
Sourcepub fn builder() -> CreateAuthCodeOutputBuilder
pub fn builder() -> CreateAuthCodeOutputBuilder
Creates a new builder-style object to manufacture CreateAuthCodeOutput.