#[non_exhaustive]pub struct CreateNotificationInputBuilder { /* private fields */ }Expand description
A builder for CreateNotificationInput.
Implementations
Sourceimpl CreateNotificationInputBuilder
impl CreateNotificationInputBuilder
Sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
This field is required.Sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn get_instance_id(&self) -> &Option<String>
pub fn get_instance_id(&self) -> &Option<String>
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn expires_at(self, input: DateTime) -> Self
pub fn expires_at(self, input: DateTime) -> Self
The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.
Sourcepub fn set_expires_at(self, input: Option<DateTime>) -> Self
pub fn set_expires_at(self, input: Option<DateTime>) -> Self
The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.
Sourcepub fn get_expires_at(&self) -> &Option<DateTime>
pub fn get_expires_at(&self) -> &Option<DateTime>
The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.
Sourcepub fn recipients(self, input: impl Into<String>) -> Self
pub fn recipients(self, input: impl Into<String>) -> Self
Appends an item to recipients.
To override the contents of this collection use set_recipients.
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.
Sourcepub fn set_recipients(self, input: Option<Vec<String>>) -> Self
pub fn set_recipients(self, input: Option<Vec<String>>) -> Self
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.
Sourcepub fn get_recipients(&self) -> &Option<Vec<String>>
pub fn get_recipients(&self) -> &Option<Vec<String>>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.
Sourcepub fn priority(self, input: ConfigurableNotificationPriority) -> Self
pub fn priority(self, input: ConfigurableNotificationPriority) -> Self
The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.
Sourcepub fn set_priority(
self,
input: Option<ConfigurableNotificationPriority>,
) -> Self
pub fn set_priority( self, input: Option<ConfigurableNotificationPriority>, ) -> Self
The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.
Sourcepub fn get_priority(&self) -> &Option<ConfigurableNotificationPriority>
pub fn get_priority(&self) -> &Option<ConfigurableNotificationPriority>
The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.
Sourcepub fn content(self, k: LocaleCode, v: impl Into<String>) -> Self
pub fn content(self, k: LocaleCode, v: impl Into<String>) -> Self
Adds a key-value pair to content.
To override the contents of this collection use set_content.
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.
Sourcepub fn set_content(self, input: Option<HashMap<LocaleCode, String>>) -> Self
pub fn set_content(self, input: Option<HashMap<LocaleCode, String>>) -> Self
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.
Sourcepub fn get_content(&self) -> &Option<HashMap<LocaleCode, String>>
pub fn get_content(&self) -> &Option<HashMap<LocaleCode, String>>
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
Sourcepub fn predefined_notification_id(self, input: impl Into<String>) -> Self
👎Deprecated since 3/13/2026: PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
pub fn predefined_notification_id(self, input: impl Into<String>) -> Self
PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
The unique identifier for a notification.
Sourcepub fn set_predefined_notification_id(self, input: Option<String>) -> Self
👎Deprecated since 3/13/2026: PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
pub fn set_predefined_notification_id(self, input: Option<String>) -> Self
PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
The unique identifier for a notification.
Sourcepub fn get_predefined_notification_id(&self) -> &Option<String>
👎Deprecated since 3/13/2026: PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
pub fn get_predefined_notification_id(&self) -> &Option<String>
PredefinedNotificationId is deprecated. Use ClientToken for idempotency.
The unique identifier for a notification.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourcepub fn build(self) -> Result<CreateNotificationInput, BuildError>
pub fn build(self) -> Result<CreateNotificationInput, BuildError>
Consumes the builder and constructs a CreateNotificationInput.
Sourceimpl CreateNotificationInputBuilder
impl CreateNotificationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateNotificationOutput, SdkError<CreateNotificationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateNotificationOutput, SdkError<CreateNotificationError, HttpResponse>>
Sends a request with this input using the given client.