CreateNotificationInput

Struct CreateNotificationInput 

#[non_exhaustive]
pub struct CreateNotificationInput { pub instance_id: Option<String>, pub expires_at: Option<DateTime>, pub recipients: Option<Vec<String>>, pub priority: Option<ConfigurableNotificationPriority>, pub content: Option<HashMap<LocaleCode, String>>, pub tags: Option<HashMap<String, String>>, pub predefined_notification_id: Option<String>, pub client_token: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
instance_id: Option<String>

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

expires_at: Option<DateTime>

The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.

recipients: Option<Vec<String>>

A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.

priority: Option<ConfigurableNotificationPriority>

The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.

content: Option<HashMap<LocaleCode, String>>

The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.

tags: Option<HashMap<String, String>>

The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.

predefined_notification_id: Option<String>
👎Deprecated since 3/13/2026:

PredefinedNotificationId is deprecated. Use ClientToken for idempotency.

The unique identifier for a notification.

client_token: Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Implementations

Source

impl CreateNotificationInput

pub fn instance_id(&self) -> Option<&str>

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

pub fn expires_at(&self) -> Option<&DateTime>

The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.

pub fn recipients(&self) -> &[String]

A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .recipients.is_none().

pub fn priority(&self) -> Option<&ConfigurableNotificationPriority>

The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.

pub fn content(&self) -> Option<&HashMap<LocaleCode, String>>

The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.

pub fn predefined_notification_id(&self) -> Option<&str>

👎Deprecated since 3/13/2026:

PredefinedNotificationId is deprecated. Use ClientToken for idempotency.

The unique identifier for a notification.

pub fn client_token(&self) -> Option<&str>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Source

impl CreateNotificationInput

pub fn builder() -> CreateNotificationInputBuilder

Creates a new builder-style object to manufacture CreateNotificationInput.