#[non_exhaustive]pub struct CreateTestCaseInputBuilder { /* private fields */ }Expand description
A builder for CreateTestCaseInput.
Implementations
Sourceimpl CreateTestCaseInputBuilder
impl CreateTestCaseInputBuilder
Sourcepub fn instance_id(self, input: impl Into<String>) -> Self
pub fn instance_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon Connect instance.
This field is required.Sourcepub fn set_instance_id(self, input: Option<String>) -> Self
pub fn set_instance_id(self, input: Option<String>) -> Self
The identifier of the Amazon Connect instance.
Sourcepub fn get_instance_id(&self) -> &Option<String>
pub fn get_instance_id(&self) -> &Option<String>
The identifier of the Amazon Connect instance.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the test.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the test.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the test.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the test.
Sourcepub fn content(self, input: impl Into<String>) -> Self
pub fn content(self, input: impl Into<String>) -> Self
The JSON string that represents the content of the test.
This field is required.Sourcepub fn set_content(self, input: Option<String>) -> Self
pub fn set_content(self, input: Option<String>) -> Self
The JSON string that represents the content of the test.
Sourcepub fn get_content(&self) -> &Option<String>
pub fn get_content(&self) -> &Option<String>
The JSON string that represents the content of the test.
Sourcepub fn entry_point(self, input: TestCaseEntryPoint) -> Self
pub fn entry_point(self, input: TestCaseEntryPoint) -> Self
Defines the starting point for your test.
Sourcepub fn set_entry_point(self, input: Option<TestCaseEntryPoint>) -> Self
pub fn set_entry_point(self, input: Option<TestCaseEntryPoint>) -> Self
Defines the starting point for your test.
Sourcepub fn get_entry_point(&self) -> &Option<TestCaseEntryPoint>
pub fn get_entry_point(&self) -> &Option<TestCaseEntryPoint>
Defines the starting point for your test.
Sourcepub fn initialization_data(self, input: impl Into<String>) -> Self
pub fn initialization_data(self, input: impl Into<String>) -> Self
Defines the initial custom attributes for your test.
Sourcepub fn set_initialization_data(self, input: Option<String>) -> Self
pub fn set_initialization_data(self, input: Option<String>) -> Self
Defines the initial custom attributes for your test.
Sourcepub fn get_initialization_data(&self) -> &Option<String>
pub fn get_initialization_data(&self) -> &Option<String>
Defines the initial custom attributes for your test.
Sourcepub fn status(self, input: TestCaseStatus) -> Self
pub fn status(self, input: TestCaseStatus) -> Self
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
Sourcepub fn set_status(self, input: Option<TestCaseStatus>) -> Self
pub fn set_status(self, input: Option<TestCaseStatus>) -> Self
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
Sourcepub fn get_status(&self) -> &Option<TestCaseStatus>
pub fn get_status(&self) -> &Option<TestCaseStatus>
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
Sourcepub fn test_case_id(self, input: impl Into<String>) -> Self
pub fn test_case_id(self, input: impl Into<String>) -> Self
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
Sourcepub fn set_test_case_id(self, input: Option<String>) -> Self
pub fn set_test_case_id(self, input: Option<String>) -> Self
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
Sourcepub fn get_test_case_id(&self) -> &Option<String>
pub fn get_test_case_id(&self) -> &Option<String>
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags used to organize, track, or control access for this resource.
The tags used to organize, track, or control access for this resource.
The tags used to organize, track, or control access for this resource.
Sourcepub fn last_modified_time(self, input: DateTime) -> Self
pub fn last_modified_time(self, input: DateTime) -> Self
The time at which the resource was last modified.
Sourcepub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
The time at which the resource was last modified.
Sourcepub fn get_last_modified_time(&self) -> &Option<DateTime>
pub fn get_last_modified_time(&self) -> &Option<DateTime>
The time at which the resource was last modified.
Sourcepub fn last_modified_region(self, input: impl Into<String>) -> Self
pub fn last_modified_region(self, input: impl Into<String>) -> Self
The region in which the resource was last modified
Sourcepub fn set_last_modified_region(self, input: Option<String>) -> Self
pub fn set_last_modified_region(self, input: Option<String>) -> Self
The region in which the resource was last modified
Sourcepub fn get_last_modified_region(&self) -> &Option<String>
pub fn get_last_modified_region(&self) -> &Option<String>
The region in which the resource was last modified
Sourcepub fn build(self) -> Result<CreateTestCaseInput, BuildError>
pub fn build(self) -> Result<CreateTestCaseInput, BuildError>
Consumes the builder and constructs a CreateTestCaseInput.
Sourceimpl CreateTestCaseInputBuilder
impl CreateTestCaseInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateTestCaseOutput, SdkError<CreateTestCaseError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateTestCaseOutput, SdkError<CreateTestCaseError, HttpResponse>>
Sends a request with this input using the given client.