#[non_exhaustive]pub struct CreateTestCaseInput {
pub instance_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub content: Option<String>,
pub entry_point: Option<TestCaseEntryPoint>,
pub initialization_data: Option<String>,
pub status: Option<TestCaseStatus>,
pub test_case_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub last_modified_time: Option<DateTime>,
pub last_modified_region: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The identifier of the Amazon Connect instance.
name: Option<String>The name of the test.
description: Option<String>The description of the test.
content: Option<String>The JSON string that represents the content of the test.
entry_point: Option<TestCaseEntryPoint>Defines the starting point for your test.
initialization_data: Option<String>Defines the initial custom attributes for your test.
status: Option<TestCaseStatus>Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
test_case_id: Option<String>Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
The tags used to organize, track, or control access for this resource.
last_modified_time: Option<DateTime>The time at which the resource was last modified.
last_modified_region: Option<String>The region in which the resource was last modified
Implementations
Sourceimpl CreateTestCaseInput
impl CreateTestCaseInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the test.
Sourcepub fn entry_point(&self) -> Option<&TestCaseEntryPoint>
pub fn entry_point(&self) -> Option<&TestCaseEntryPoint>
Defines the starting point for your test.
Sourcepub fn initialization_data(&self) -> Option<&str>
pub fn initialization_data(&self) -> Option<&str>
Defines the initial custom attributes for your test.
Sourcepub fn status(&self) -> Option<&TestCaseStatus>
pub fn status(&self) -> Option<&TestCaseStatus>
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
Sourcepub fn test_case_id(&self) -> Option<&str>
pub fn test_case_id(&self) -> Option<&str>
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
The tags used to organize, track, or control access for this resource.
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The time at which the resource was last modified.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The region in which the resource was last modified
Sourceimpl CreateTestCaseInput
impl CreateTestCaseInput
Sourcepub fn builder() -> CreateTestCaseInputBuilder
pub fn builder() -> CreateTestCaseInputBuilder
Creates a new builder-style object to manufacture CreateTestCaseInput.