#[non_exhaustive]pub enum DeleteContactDataError {
ContactNotTerminatedException(ContactNotTerminatedException),
InternalServiceException(InternalServiceException),
InvalidParameterException(InvalidParameterException),
InvalidRequestException(InvalidRequestException),
ResourceNotFoundException(ResourceNotFoundException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the DeleteContactDataError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ContactNotTerminatedException(ContactNotTerminatedException)
The contact has not been disconnected and is not in a terminated state. PII can be deleted only from a contact that has been disconnected. This error is returned with an HTTP 409 status code.
InternalServiceException(InternalServiceException)
Request processing failed because of an error or failure with the service.
InvalidParameterException(InvalidParameterException)
One or more of the specified parameters are not valid.
InvalidRequestException(InvalidRequestException)
The request is not valid.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource was not found.
ThrottlingException(ThrottlingException)
The throttling limit has been exceeded.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DeleteContactDataError
impl DeleteContactDataError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DeleteContactDataError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DeleteContactDataError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_contact_not_terminated_exception(&self) -> bool
pub fn is_contact_not_terminated_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::ContactNotTerminatedException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::InternalServiceException.
Sourcepub fn is_invalid_parameter_exception(&self) -> bool
pub fn is_invalid_parameter_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::InvalidParameterException.
Sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::InvalidRequestException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::ResourceNotFoundException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is DeleteContactDataError::ThrottlingException.