#[non_exhaustive]pub struct DisassociateQueueEmailAddressesInput {
pub instance_id: Option<String>,
pub queue_id: Option<String>,
pub email_addresses_id: Option<Vec<String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
queue_id: Option<String>The identifier for the queue.
email_addresses_id: Option<Vec<String>>List of email address identifiers to disassociate from the queue. These are the unique identifiers of email addresses that should no longer be routed to this queue.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Implementations
Sourceimpl DisassociateQueueEmailAddressesInput
impl DisassociateQueueEmailAddressesInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn email_addresses_id(&self) -> &[String]
pub fn email_addresses_id(&self) -> &[String]
List of email address identifiers to disassociate from the queue. These are the unique identifiers of email addresses that should no longer be routed to this queue.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .email_addresses_id.is_none().
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourceimpl DisassociateQueueEmailAddressesInput
impl DisassociateQueueEmailAddressesInput
Sourcepub fn builder() -> DisassociateQueueEmailAddressesInputBuilder
pub fn builder() -> DisassociateQueueEmailAddressesInputBuilder
Creates a new builder-style object to manufacture DisassociateQueueEmailAddressesInput.