#[non_exhaustive]pub struct ListQueueEmailAddressesOutput {
pub next_token: Option<String>,
pub email_address_metadata_list: Option<Vec<EmailAddressSummary>>,
pub last_modified_time: Option<DateTime>,
pub last_modified_region: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>If there are additional results, this is the token for the next set of results.
email_address_metadata_list: Option<Vec<EmailAddressSummary>>List of email address summary information for all email addresses associated with the queue. Each item contains the email address identifier, ARN, and configuration details.
last_modified_time: Option<DateTime>The timestamp when this resource was last modified.
last_modified_region: Option<String>The Amazon Web Services Region where this resource was last modified.
Implementations
Sourceimpl ListQueueEmailAddressesOutput
impl ListQueueEmailAddressesOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If there are additional results, this is the token for the next set of results.
Sourcepub fn email_address_metadata_list(&self) -> &[EmailAddressSummary]
pub fn email_address_metadata_list(&self) -> &[EmailAddressSummary]
List of email address summary information for all email addresses associated with the queue. Each item contains the email address identifier, ARN, and configuration details.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .email_address_metadata_list.is_none().
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The timestamp when this resource was last modified.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The Amazon Web Services Region where this resource was last modified.
Sourceimpl ListQueueEmailAddressesOutput
impl ListQueueEmailAddressesOutput
Sourcepub fn builder() -> ListQueueEmailAddressesOutputBuilder
pub fn builder() -> ListQueueEmailAddressesOutputBuilder
Creates a new builder-style object to manufacture ListQueueEmailAddressesOutput.