#[non_exhaustive]pub struct StartTestCaseExecutionInput {
pub instance_id: Option<String>,
pub test_case_id: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The identifier of the Amazon Connect instance.
test_case_id: Option<String>The identifier of the test case to execute.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Implementations
Sourceimpl StartTestCaseExecutionInput
impl StartTestCaseExecutionInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance.
Sourcepub fn test_case_id(&self) -> Option<&str>
pub fn test_case_id(&self) -> Option<&str>
The identifier of the test case to execute.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Sourceimpl StartTestCaseExecutionInput
impl StartTestCaseExecutionInput
Sourcepub fn builder() -> StartTestCaseExecutionInputBuilder
pub fn builder() -> StartTestCaseExecutionInputBuilder
Creates a new builder-style object to manufacture StartTestCaseExecutionInput.