#[non_exhaustive]pub struct UpdateTestCaseInput {
pub instance_id: Option<String>,
pub test_case_id: Option<String>,
pub content: Option<String>,
pub entry_point: Option<TestCaseEntryPoint>,
pub initialization_data: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub status: Option<TestCaseStatus>,
pub last_modified_time: Option<DateTime>,
pub last_modified_region: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The identifier of the Amazon Connect instance.
test_case_id: Option<String>The identifier of the test case to update.
content: Option<String>The JSON string that represents the content of the test.
entry_point: Option<TestCaseEntryPoint>Defines the starting point for your test.
initialization_data: Option<String>Defines the test attributes for precise data representation.
name: Option<String>The name of the test case.
description: Option<String>The description of the test case.
status: Option<TestCaseStatus>Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
last_modified_time: Option<DateTime>The time at which the resource was last modified.
last_modified_region: Option<String>The region in which the resource was last modified
Implementations
Sourceimpl UpdateTestCaseInput
impl UpdateTestCaseInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance.
Sourcepub fn test_case_id(&self) -> Option<&str>
pub fn test_case_id(&self) -> Option<&str>
The identifier of the test case to update.
Sourcepub fn entry_point(&self) -> Option<&TestCaseEntryPoint>
pub fn entry_point(&self) -> Option<&TestCaseEntryPoint>
Defines the starting point for your test.
Sourcepub fn initialization_data(&self) -> Option<&str>
pub fn initialization_data(&self) -> Option<&str>
Defines the test attributes for precise data representation.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the test case.
Sourcepub fn status(&self) -> Option<&TestCaseStatus>
pub fn status(&self) -> Option<&TestCaseStatus>
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The time at which the resource was last modified.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The region in which the resource was last modified
Sourceimpl UpdateTestCaseInput
impl UpdateTestCaseInput
Sourcepub fn builder() -> UpdateTestCaseInputBuilder
pub fn builder() -> UpdateTestCaseInputBuilder
Creates a new builder-style object to manufacture UpdateTestCaseInput.