#[non_exhaustive]pub struct UpdateUserConfigInput {
pub auto_accept_configs: Option<Vec<AutoAcceptConfig>>,
pub after_contact_work_configs: Option<Vec<AfterContactWorkConfigPerChannel>>,
pub phone_number_configs: Option<Vec<PhoneNumberConfig>>,
pub persistent_connection_configs: Option<Vec<PersistentConnectionConfig>>,
pub voice_enhancement_configs: Option<Vec<VoiceEnhancementConfig>>,
pub user_id: Option<String>,
pub instance_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auto_accept_configs: Option<Vec<AutoAcceptConfig>>The list of auto-accept configuration settings for each channel. When auto-accept is enabled for a channel, available agents are automatically connected to contacts from that channel without needing to manually accept. Auto-accept connects agents to contacts in less than one second.
after_contact_work_configs: Option<Vec<AfterContactWorkConfigPerChannel>>The list of after contact work (ACW) timeout configuration settings for each channel. ACW timeout specifies how many seconds agents have for after contact work, such as entering notes about the contact. The minimum setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter 0 for an indefinite amount of time, meaning agents must manually choose to end ACW.
phone_number_configs: Option<Vec<PhoneNumberConfig>>The list of phone number configuration settings for each channel.
persistent_connection_configs: Option<Vec<PersistentConnectionConfig>>The list of persistent connection configuration settings for each channel.
voice_enhancement_configs: Option<Vec<VoiceEnhancementConfig>>The list of voice enhancement configuration settings for each channel.
user_id: Option<String>The identifier of the user account.
instance_id: Option<String>The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Implementations
Sourceimpl UpdateUserConfigInput
impl UpdateUserConfigInput
Sourcepub fn auto_accept_configs(&self) -> &[AutoAcceptConfig]
pub fn auto_accept_configs(&self) -> &[AutoAcceptConfig]
The list of auto-accept configuration settings for each channel. When auto-accept is enabled for a channel, available agents are automatically connected to contacts from that channel without needing to manually accept. Auto-accept connects agents to contacts in less than one second.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .auto_accept_configs.is_none().
Sourcepub fn after_contact_work_configs(&self) -> &[AfterContactWorkConfigPerChannel]
pub fn after_contact_work_configs(&self) -> &[AfterContactWorkConfigPerChannel]
The list of after contact work (ACW) timeout configuration settings for each channel. ACW timeout specifies how many seconds agents have for after contact work, such as entering notes about the contact. The minimum setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter 0 for an indefinite amount of time, meaning agents must manually choose to end ACW.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .after_contact_work_configs.is_none().
Sourcepub fn phone_number_configs(&self) -> &[PhoneNumberConfig]
pub fn phone_number_configs(&self) -> &[PhoneNumberConfig]
The list of phone number configuration settings for each channel.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .phone_number_configs.is_none().
Sourcepub fn persistent_connection_configs(&self) -> &[PersistentConnectionConfig]
pub fn persistent_connection_configs(&self) -> &[PersistentConnectionConfig]
The list of persistent connection configuration settings for each channel.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .persistent_connection_configs.is_none().
Sourcepub fn voice_enhancement_configs(&self) -> &[VoiceEnhancementConfig]
pub fn voice_enhancement_configs(&self) -> &[VoiceEnhancementConfig]
The list of voice enhancement configuration settings for each channel.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .voice_enhancement_configs.is_none().
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourceimpl UpdateUserConfigInput
impl UpdateUserConfigInput
Sourcepub fn builder() -> UpdateUserConfigInputBuilder
pub fn builder() -> UpdateUserConfigInputBuilder
Creates a new builder-style object to manufacture UpdateUserConfigInput.