#[non_exhaustive]pub struct UpdateUserNotificationStatusInput {
pub instance_id: Option<String>,
pub notification_id: Option<String>,
pub user_id: Option<String>,
pub status: Option<NotificationStatus>,
pub last_modified_time: Option<DateTime>,
pub last_modified_region: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
notification_id: Option<String>The unique identifier for the notification.
user_id: Option<String>The identifier of the user whose notification status is being updated.
status: Option<NotificationStatus>The new status for the notification. Valid values are READ, UNREAD, and HIDDEN.
last_modified_time: Option<DateTime>The timestamp when the notification status was last modified. Used for cross-region replication and optimistic locking.
last_modified_region: Option<String>The AWS Region where the notification status was last modified. Used for cross-region replication.
Implementations
Sourceimpl UpdateUserNotificationStatusInput
impl UpdateUserNotificationStatusInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
Sourcepub fn notification_id(&self) -> Option<&str>
pub fn notification_id(&self) -> Option<&str>
The unique identifier for the notification.
Sourcepub fn user_id(&self) -> Option<&str>
pub fn user_id(&self) -> Option<&str>
The identifier of the user whose notification status is being updated.
Sourcepub fn status(&self) -> Option<&NotificationStatus>
pub fn status(&self) -> Option<&NotificationStatus>
The new status for the notification. Valid values are READ, UNREAD, and HIDDEN.
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The timestamp when the notification status was last modified. Used for cross-region replication and optimistic locking.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The AWS Region where the notification status was last modified. Used for cross-region replication.
Sourceimpl UpdateUserNotificationStatusInput
impl UpdateUserNotificationStatusInput
Sourcepub fn builder() -> UpdateUserNotificationStatusInputBuilder
pub fn builder() -> UpdateUserNotificationStatusInputBuilder
Creates a new builder-style object to manufacture UpdateUserNotificationStatusInput.