#[non_exhaustive]pub struct EmailAddressConfigBuilder { /* private fields */ }Expand description
A builder for EmailAddressConfig.
Implementations
Sourceimpl EmailAddressConfigBuilder
impl EmailAddressConfigBuilder
Sourcepub fn email_address_id(self, input: impl Into<String>) -> Self
pub fn email_address_id(self, input: impl Into<String>) -> Self
The identifier of the email address that should be associated with the queue. This email address must already exist in the Amazon Connect instance and will be used to route incoming email contacts to the specified queue.
This field is required.Sourcepub fn set_email_address_id(self, input: Option<String>) -> Self
pub fn set_email_address_id(self, input: Option<String>) -> Self
The identifier of the email address that should be associated with the queue. This email address must already exist in the Amazon Connect instance and will be used to route incoming email contacts to the specified queue.
Sourcepub fn get_email_address_id(&self) -> &Option<String>
pub fn get_email_address_id(&self) -> &Option<String>
The identifier of the email address that should be associated with the queue. This email address must already exist in the Amazon Connect instance and will be used to route incoming email contacts to the specified queue.
Sourcepub fn build(self) -> Result<EmailAddressConfig, BuildError>
pub fn build(self) -> Result<EmailAddressConfig, BuildError>
Consumes the builder and constructs a EmailAddressConfig.
This method will fail if any of the following fields are not set: