#[non_exhaustive]pub struct NotificationBuilder { /* private fields */ }Expand description
A builder for Notification.
Implementations
Sourceimpl NotificationBuilder
impl NotificationBuilder
Sourcepub fn content(self, k: LocaleCode, v: impl Into<String>) -> Self
pub fn content(self, k: LocaleCode, v: impl Into<String>) -> Self
Adds a key-value pair to content.
To override the contents of this collection use set_content.
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
Sourcepub fn set_content(self, input: Option<HashMap<LocaleCode, String>>) -> Self
pub fn set_content(self, input: Option<HashMap<LocaleCode, String>>) -> Self
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
Sourcepub fn get_content(&self) -> &Option<HashMap<LocaleCode, String>>
pub fn get_content(&self) -> &Option<HashMap<LocaleCode, String>>
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The unique identifier for the notification.
This field is required.Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the notification.
This field is required.Sourcepub fn set_arn(self, input: Option<String>) -> Self
pub fn set_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the notification.
Sourcepub fn priority(self, input: NotificationPriority) -> Self
pub fn priority(self, input: NotificationPriority) -> Self
The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
Sourcepub fn set_priority(self, input: Option<NotificationPriority>) -> Self
pub fn set_priority(self, input: Option<NotificationPriority>) -> Self
The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
Sourcepub fn get_priority(&self) -> &Option<NotificationPriority>
pub fn get_priority(&self) -> &Option<NotificationPriority>
The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
Sourcepub fn recipients(self, input: impl Into<String>) -> Self
pub fn recipients(self, input: impl Into<String>) -> Self
Appends an item to recipients.
To override the contents of this collection use set_recipients.
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
Sourcepub fn set_recipients(self, input: Option<Vec<String>>) -> Self
pub fn set_recipients(self, input: Option<Vec<String>>) -> Self
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
Sourcepub fn get_recipients(&self) -> &Option<Vec<String>>
pub fn get_recipients(&self) -> &Option<Vec<String>>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
Sourcepub fn last_modified_time(self, input: DateTime) -> Self
pub fn last_modified_time(self, input: DateTime) -> Self
The timestamp when the notification was last modified.
This field is required.Sourcepub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
The timestamp when the notification was last modified.
Sourcepub fn get_last_modified_time(&self) -> &Option<DateTime>
pub fn get_last_modified_time(&self) -> &Option<DateTime>
The timestamp when the notification was last modified.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp when the notification was created.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp when the notification was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp when the notification was created.
Sourcepub fn expires_at(self, input: DateTime) -> Self
pub fn expires_at(self, input: DateTime) -> Self
The timestamp when the notification expires and is no longer displayed to users.
Sourcepub fn set_expires_at(self, input: Option<DateTime>) -> Self
pub fn set_expires_at(self, input: Option<DateTime>) -> Self
The timestamp when the notification expires and is no longer displayed to users.
Sourcepub fn get_expires_at(&self) -> &Option<DateTime>
pub fn get_expires_at(&self) -> &Option<DateTime>
The timestamp when the notification expires and is no longer displayed to users.
Sourcepub fn last_modified_region(self, input: impl Into<String>) -> Self
pub fn last_modified_region(self, input: impl Into<String>) -> Self
The AWS Region where the notification was last modified.
Sourcepub fn set_last_modified_region(self, input: Option<String>) -> Self
pub fn set_last_modified_region(self, input: Option<String>) -> Self
The AWS Region where the notification was last modified.
Sourcepub fn get_last_modified_region(&self) -> &Option<String>
pub fn get_last_modified_region(&self) -> &Option<String>
The AWS Region where the notification was last modified.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
Sourcepub fn build(self) -> Result<Notification, BuildError>
pub fn build(self) -> Result<Notification, BuildError>
Consumes the builder and constructs a Notification.
This method will fail if any of the following fields are not set: