#[non_exhaustive]pub struct PersistentConnectionConfigBuilder { /* private fields */ }Expand description
A builder for PersistentConnectionConfig.
Implementations
Sourceimpl PersistentConnectionConfigBuilder
impl PersistentConnectionConfigBuilder
Sourcepub fn channel(self, input: Channel) -> Self
pub fn channel(self, input: Channel) -> Self
Configuration settings for persistent connection. Only VOICE is supported for this data type.
Sourcepub fn set_channel(self, input: Option<Channel>) -> Self
pub fn set_channel(self, input: Option<Channel>) -> Self
Configuration settings for persistent connection. Only VOICE is supported for this data type.
Sourcepub fn get_channel(&self) -> &Option<Channel>
pub fn get_channel(&self) -> &Option<Channel>
Configuration settings for persistent connection. Only VOICE is supported for this data type.
Sourcepub fn persistent_connection(self, input: bool) -> Self
pub fn persistent_connection(self, input: bool) -> Self
Indicates whether persistent connection is enabled. When enabled, the agent's connection is maintained after a call ends, enabling subsequent calls to connect faster.
This field is required.Sourcepub fn set_persistent_connection(self, input: Option<bool>) -> Self
pub fn set_persistent_connection(self, input: Option<bool>) -> Self
Indicates whether persistent connection is enabled. When enabled, the agent's connection is maintained after a call ends, enabling subsequent calls to connect faster.
Sourcepub fn get_persistent_connection(&self) -> &Option<bool>
pub fn get_persistent_connection(&self) -> &Option<bool>
Indicates whether persistent connection is enabled. When enabled, the agent's connection is maintained after a call ends, enabling subsequent calls to connect faster.
Sourcepub fn build(self) -> Result<PersistentConnectionConfig, BuildError>
pub fn build(self) -> Result<PersistentConnectionConfig, BuildError>
Consumes the builder and constructs a PersistentConnectionConfig.
This method will fail if any of the following fields are not set: