RecurrencePatternBuilder

Struct RecurrencePatternBuilder 

#[non_exhaustive]
pub struct RecurrencePatternBuilder { /* private fields */ }
A builder for RecurrencePattern.

Implementations

Source

impl RecurrencePatternBuilder

pub fn frequency(self, input: RecurrenceFrequency) -> Self

Defines how often the pattern repeats. This is the base unit for the recurrence schedule and works in conjunction with the Interval field to determine the exact repetition sequence.

This field is required.
pub fn set_frequency(self, input: Option<RecurrenceFrequency>) -> Self

Defines how often the pattern repeats. This is the base unit for the recurrence schedule and works in conjunction with the Interval field to determine the exact repetition sequence.

pub fn get_frequency(&self) -> &Option<RecurrenceFrequency>

Defines how often the pattern repeats. This is the base unit for the recurrence schedule and works in conjunction with the Interval field to determine the exact repetition sequence.

pub fn interval(self, input: i32) -> Self

Specifies the number of frequency units between each occurrence. Must be a positive integer.

Examples: To repeat every week, set Interval=1 with WEEKLY frequency. To repeat every two months, set Interval=2 with MONTHLY frequency.

This field is required.
pub fn set_interval(self, input: Option<i32>) -> Self

Specifies the number of frequency units between each occurrence. Must be a positive integer.

Examples: To repeat every week, set Interval=1 with WEEKLY frequency. To repeat every two months, set Interval=2 with MONTHLY frequency.

pub fn get_interval(&self) -> &Option<i32>

Specifies the number of frequency units between each occurrence. Must be a positive integer.

Examples: To repeat every week, set Interval=1 with WEEKLY frequency. To repeat every two months, set Interval=2 with MONTHLY frequency.

pub fn by_month(self, input: i32) -> Self

Appends an item to by_month.

To override the contents of this collection use set_by_month.

Specifies which month the event should occur in (1-12, where 1=January, 12=December). Used with YEARLY frequency to schedule events in specific month.

Note: It does not accept multiple values in the same list

pub fn set_by_month(self, input: Option<Vec<i32>>) -> Self

Specifies which month the event should occur in (1-12, where 1=January, 12=December). Used with YEARLY frequency to schedule events in specific month.

Note: It does not accept multiple values in the same list

pub fn get_by_month(&self) -> &Option<Vec<i32>>

Specifies which month the event should occur in (1-12, where 1=January, 12=December). Used with YEARLY frequency to schedule events in specific month.

Note: It does not accept multiple values in the same list

pub fn by_month_day(self, input: i32) -> Self

Appends an item to by_month_day.

To override the contents of this collection use set_by_month_day.

Specifies which day of the month the event should occur on (1-31). Used with MONTHLY or YEARLY frequency to schedule events on specific date within a month.

Examples: \[15\] for events on the 15th of each month, \[-1\] for events on the last day of month.

Note: It does not accept multiple values in the same list. If a specified day doesn't exist in a particular month (e.g., day 31 in February), the event will be skipped for that month. This field cannot be used simultaneously with ByWeekdayOccurrence as they represent different scheduling approaches (specific dates vs. relative weekday positions).

pub fn set_by_month_day(self, input: Option<Vec<i32>>) -> Self

Specifies which day of the month the event should occur on (1-31). Used with MONTHLY or YEARLY frequency to schedule events on specific date within a month.

Examples: \[15\] for events on the 15th of each month, \[-1\] for events on the last day of month.

Note: It does not accept multiple values in the same list. If a specified day doesn't exist in a particular month (e.g., day 31 in February), the event will be skipped for that month. This field cannot be used simultaneously with ByWeekdayOccurrence as they represent different scheduling approaches (specific dates vs. relative weekday positions).

pub fn get_by_month_day(&self) -> &Option<Vec<i32>>

Specifies which day of the month the event should occur on (1-31). Used with MONTHLY or YEARLY frequency to schedule events on specific date within a month.

Examples: \[15\] for events on the 15th of each month, \[-1\] for events on the last day of month.

Note: It does not accept multiple values in the same list. If a specified day doesn't exist in a particular month (e.g., day 31 in February), the event will be skipped for that month. This field cannot be used simultaneously with ByWeekdayOccurrence as they represent different scheduling approaches (specific dates vs. relative weekday positions).

pub fn by_weekday_occurrence(self, input: i32) -> Self

Appends an item to by_weekday_occurrence.

To override the contents of this collection use set_by_weekday_occurrence.

Specifies which occurrence of a weekday within the month the event should occur on. Must be used with MONTHLY or YEARLY frequency.

Example: 2 corresponds to second occurrence of the weekday in the month. -1 corresponds to last occurrence of the weekday in the month

The weekday itself is specified separately in the HoursOfOperationConfig. Example: To schedule the recurring event for the 2nd Thursday of April every year, set ByWeekdayOccurrence=\[2\], Day=THURSDAY, ByMonth=\[4\], Frequency: YEARLY and INTERVAL=1.

pub fn set_by_weekday_occurrence(self, input: Option<Vec<i32>>) -> Self

Specifies which occurrence of a weekday within the month the event should occur on. Must be used with MONTHLY or YEARLY frequency.

Example: 2 corresponds to second occurrence of the weekday in the month. -1 corresponds to last occurrence of the weekday in the month

The weekday itself is specified separately in the HoursOfOperationConfig. Example: To schedule the recurring event for the 2nd Thursday of April every year, set ByWeekdayOccurrence=\[2\], Day=THURSDAY, ByMonth=\[4\], Frequency: YEARLY and INTERVAL=1.

pub fn get_by_weekday_occurrence(&self) -> &Option<Vec<i32>>

Specifies which occurrence of a weekday within the month the event should occur on. Must be used with MONTHLY or YEARLY frequency.

Example: 2 corresponds to second occurrence of the weekday in the month. -1 corresponds to last occurrence of the weekday in the month

The weekday itself is specified separately in the HoursOfOperationConfig. Example: To schedule the recurring event for the 2nd Thursday of April every year, set ByWeekdayOccurrence=\[2\], Day=THURSDAY, ByMonth=\[4\], Frequency: YEARLY and INTERVAL=1.

pub fn build(self) -> Result<RecurrencePattern, BuildError>

Consumes the builder and constructs a RecurrencePattern. This method will fail if any of the following fields are not set: