#[non_exhaustive]pub struct AutoAcceptConfig {
pub channel: Channel,
pub auto_accept: bool,
pub agent_first_callback_auto_accept: Option<bool>,
}Expand description
Configuration settings for auto-accept for a specific channel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: ChannelThe channel for this auto-accept configuration. Valid values: VOICE, CHAT, TASK, EMAIL.
auto_accept: boolIndicates whether auto-accept is enabled for this channel. When enabled, available agents are automatically connected to contacts from this channel.
agent_first_callback_auto_accept: Option<bool>Indicates whether auto-accept is enabled for agent-first callbacks. This setting only applies to the VOICE channel.
Implementations
Sourceimpl AutoAcceptConfig
impl AutoAcceptConfig
Sourcepub fn channel(&self) -> &Channel
pub fn channel(&self) -> &Channel
The channel for this auto-accept configuration. Valid values: VOICE, CHAT, TASK, EMAIL.
Sourcepub fn auto_accept(&self) -> bool
pub fn auto_accept(&self) -> bool
Indicates whether auto-accept is enabled for this channel. When enabled, available agents are automatically connected to contacts from this channel.
Sourcepub fn agent_first_callback_auto_accept(&self) -> Option<bool>
pub fn agent_first_callback_auto_accept(&self) -> Option<bool>
Indicates whether auto-accept is enabled for agent-first callbacks. This setting only applies to the VOICE channel.
Sourceimpl AutoAcceptConfig
impl AutoAcceptConfig
Sourcepub fn builder() -> AutoAcceptConfigBuilder
pub fn builder() -> AutoAcceptConfigBuilder
Creates a new builder-style object to manufacture AutoAcceptConfig.