#[non_exhaustive]pub struct EmailAddressSummary {
pub id: Option<String>,
pub arn: Option<String>,
pub is_default_outbound_email: bool,
}Expand description
Summary information about an email address associated with a queue. Contains the essential details needed to identify and manage the email address routing configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the email address associated with the queue.
arn: Option<String>The Amazon Resource Name (ARN) of the email address associated with the queue.
is_default_outbound_email: boolIndicates whether this email address is configured as the default outbound email address for the queue. When set to true, this email address is used as the default sender for outbound email contacts from this queue.
Implementations
Sourceimpl EmailAddressSummary
impl EmailAddressSummary
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
The unique identifier of the email address associated with the queue.
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the email address associated with the queue.
Sourcepub fn is_default_outbound_email(&self) -> bool
pub fn is_default_outbound_email(&self) -> bool
Indicates whether this email address is configured as the default outbound email address for the queue. When set to true, this email address is used as the default sender for outbound email contacts from this queue.
Sourceimpl EmailAddressSummary
impl EmailAddressSummary
Sourcepub fn builder() -> EmailAddressSummaryBuilder
pub fn builder() -> EmailAddressSummaryBuilder
Creates a new builder-style object to manufacture EmailAddressSummary.