#[non_exhaustive]pub struct EvaluationReviewRequestComment {
pub comment: Option<String>,
pub created_time: Option<DateTime>,
pub created_by: Option<String>,
}Expand description
A comment provided when requesting an evaluation review.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.comment: Option<String>The text content of the review request comment.
created_time: Option<DateTime>The timestamp when the evaluation review request comment was created.
created_by: Option<String>The user who created the evaluation review request comment.
Implementations
Sourceimpl EvaluationReviewRequestComment
impl EvaluationReviewRequestComment
Sourcepub fn created_time(&self) -> Option<&DateTime>
pub fn created_time(&self) -> Option<&DateTime>
The timestamp when the evaluation review request comment was created.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The user who created the evaluation review request comment.
Sourceimpl EvaluationReviewRequestComment
impl EvaluationReviewRequestComment
Sourcepub fn builder() -> EvaluationReviewRequestCommentBuilder
pub fn builder() -> EvaluationReviewRequestCommentBuilder
Creates a new builder-style object to manufacture EvaluationReviewRequestComment.