#[non_exhaustive]pub struct NotificationSearchSummary {
pub id: Option<String>,
pub arn: Option<String>,
pub instance_id: Option<String>,
pub content: Option<HashMap<LocaleCode, String>>,
pub priority: Option<NotificationPriority>,
pub recipients: Option<Vec<String>>,
pub created_at: Option<DateTime>,
pub expires_at: Option<DateTime>,
pub last_modified_region: Option<String>,
pub last_modified_time: Option<DateTime>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Summary information about a notification returned from a search operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier for the notification.
arn: Option<String>The Amazon Resource Name (ARN) of the notification.
instance_id: Option<String>The identifier of the Amazon Connect instance.
content: Option<HashMap<LocaleCode, String>>The localized content of the notification.
priority: Option<NotificationPriority>The priority level of the notification.
recipients: Option<Vec<String>>A list of recipient Amazon Resource Names (ARNs).
created_at: Option<DateTime>The timestamp when the notification was created.
expires_at: Option<DateTime>The timestamp when the notification expires.
last_modified_region: Option<String>The AWS Region where the notification was last modified.
last_modified_time: Option<DateTime>The timestamp when the notification was last modified.
The tags associated with the notification.
Implementations
Sourceimpl NotificationSearchSummary
impl NotificationSearchSummary
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The identifier of the Amazon Connect instance.
Sourcepub fn content(&self) -> Option<&HashMap<LocaleCode, String>>
pub fn content(&self) -> Option<&HashMap<LocaleCode, String>>
The localized content of the notification.
Sourcepub fn priority(&self) -> Option<&NotificationPriority>
pub fn priority(&self) -> Option<&NotificationPriority>
The priority level of the notification.
Sourcepub fn recipients(&self) -> &[String]
pub fn recipients(&self) -> &[String]
A list of recipient Amazon Resource Names (ARNs).
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .recipients.is_none().
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the notification was created.
Sourcepub fn expires_at(&self) -> Option<&DateTime>
pub fn expires_at(&self) -> Option<&DateTime>
The timestamp when the notification expires.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The AWS Region where the notification was last modified.
Sourcepub fn last_modified_time(&self) -> Option<&DateTime>
pub fn last_modified_time(&self) -> Option<&DateTime>
The timestamp when the notification was last modified.
The tags associated with the notification.
Sourceimpl NotificationSearchSummary
impl NotificationSearchSummary
Sourcepub fn builder() -> NotificationSearchSummaryBuilder
pub fn builder() -> NotificationSearchSummaryBuilder
Creates a new builder-style object to manufacture NotificationSearchSummary.