#[non_exhaustive]pub struct ObservationSummary {
pub total_observations: Option<i32>,
pub observations_passed: Option<i32>,
pub observations_failed: Option<i32>,
}Expand description
Contains summary statistics about a test case execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_observations: Option<i32>The total number of observations in the test case.
observations_passed: Option<i32>The number of observations that passed during execution.
observations_failed: Option<i32>The number of observations that failed during execution.
Implementations
Sourceimpl ObservationSummary
impl ObservationSummary
Sourcepub fn total_observations(&self) -> Option<i32>
pub fn total_observations(&self) -> Option<i32>
The total number of observations in the test case.
Sourcepub fn observations_passed(&self) -> Option<i32>
pub fn observations_passed(&self) -> Option<i32>
The number of observations that passed during execution.
Sourcepub fn observations_failed(&self) -> Option<i32>
pub fn observations_failed(&self) -> Option<i32>
The number of observations that failed during execution.
Sourceimpl ObservationSummary
impl ObservationSummary
Sourcepub fn builder() -> ObservationSummaryBuilder
pub fn builder() -> ObservationSummaryBuilder
Creates a new builder-style object to manufacture ObservationSummary.