#[non_exhaustive]pub struct OverrideHour {
pub start: Option<OverrideTimeSlice>,
pub end: Option<OverrideTimeSlice>,
pub override_name: Option<String>,
pub operational_status: Option<OperationalStatus>,
}Expand description
Information about hours of operation override
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start: Option<OverrideTimeSlice>The start time or end time for an hours of operation override.
end: Option<OverrideTimeSlice>The start time or end time for an hours of operation override.
override_name: Option<String>Unique identifier name for the override.
operational_status: Option<OperationalStatus>Indicates whether the status is open or closed during the override period. This status determines how the override modifies the base hours of operation schedule.
Implementations
Sourceimpl OverrideHour
impl OverrideHour
Sourcepub fn start(&self) -> Option<&OverrideTimeSlice>
pub fn start(&self) -> Option<&OverrideTimeSlice>
The start time or end time for an hours of operation override.
Sourcepub fn end(&self) -> Option<&OverrideTimeSlice>
pub fn end(&self) -> Option<&OverrideTimeSlice>
The start time or end time for an hours of operation override.
Sourcepub fn override_name(&self) -> Option<&str>
pub fn override_name(&self) -> Option<&str>
Unique identifier name for the override.
Sourcepub fn operational_status(&self) -> Option<&OperationalStatus>
pub fn operational_status(&self) -> Option<&OperationalStatus>
Indicates whether the status is open or closed during the override period. This status determines how the override modifies the base hours of operation schedule.
Sourceimpl OverrideHour
impl OverrideHour
Sourcepub fn builder() -> OverrideHourBuilder
pub fn builder() -> OverrideHourBuilder
Creates a new builder-style object to manufacture OverrideHour.