#[non_exhaustive]pub struct RecurrenceConfig {
pub recurrence_pattern: Option<RecurrencePattern>,
}Expand description
Defines the recurrence configuration for overrides. This configuration uses a recurrence pattern to specify when and how frequently an event should repeat.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recurrence_pattern: Option<RecurrencePattern>The recurrence pattern that defines how the event repeats. Example: Frequency, Interval, ByMonth, ByMonthDay, ByWeekdayOccurrence
Implementations
Sourceimpl RecurrenceConfig
impl RecurrenceConfig
Sourcepub fn recurrence_pattern(&self) -> Option<&RecurrencePattern>
pub fn recurrence_pattern(&self) -> Option<&RecurrencePattern>
The recurrence pattern that defines how the event repeats. Example: Frequency, Interval, ByMonth, ByMonthDay, ByWeekdayOccurrence
Sourceimpl RecurrenceConfig
impl RecurrenceConfig
Sourcepub fn builder() -> RecurrenceConfigBuilder
pub fn builder() -> RecurrenceConfigBuilder
Creates a new builder-style object to manufacture RecurrenceConfig.