RecurrencePattern

Struct RecurrencePattern 

#[non_exhaustive]
pub struct RecurrencePattern { pub frequency: RecurrenceFrequency, pub interval: i32, pub by_month: Option<Vec<i32>>, pub by_month_day: Option<Vec<i32>>, pub by_weekday_occurrence: Option<Vec<i32>>, }
Specifies the detailed pattern for event recurrence. Use this to define complex scheduling rules such as "every 2nd Tuesday of the month" or "every 3 months on the 15th".

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
frequency: RecurrenceFrequency

Defines how often the pattern repeats. This is the base unit for the recurrence schedule and works in conjunction with the Interval field to determine the exact repetition sequence.

interval: i32

Specifies the number of frequency units between each occurrence. Must be a positive integer.

Examples: To repeat every week, set Interval=1 with WEEKLY frequency. To repeat every two months, set Interval=2 with MONTHLY frequency.

by_month: Option<Vec<i32>>

Specifies which month the event should occur in (1-12, where 1=January, 12=December). Used with YEARLY frequency to schedule events in specific month.

Note: It does not accept multiple values in the same list

by_month_day: Option<Vec<i32>>

Specifies which day of the month the event should occur on (1-31). Used with MONTHLY or YEARLY frequency to schedule events on specific date within a month.

Examples: \[15\] for events on the 15th of each month, \[-1\] for events on the last day of month.

Note: It does not accept multiple values in the same list. If a specified day doesn't exist in a particular month (e.g., day 31 in February), the event will be skipped for that month. This field cannot be used simultaneously with ByWeekdayOccurrence as they represent different scheduling approaches (specific dates vs. relative weekday positions).

by_weekday_occurrence: Option<Vec<i32>>

Specifies which occurrence of a weekday within the month the event should occur on. Must be used with MONTHLY or YEARLY frequency.

Example: 2 corresponds to second occurrence of the weekday in the month. -1 corresponds to last occurrence of the weekday in the month

The weekday itself is specified separately in the HoursOfOperationConfig. Example: To schedule the recurring event for the 2nd Thursday of April every year, set ByWeekdayOccurrence=\[2\], Day=THURSDAY, ByMonth=\[4\], Frequency: YEARLY and INTERVAL=1.

Implementations

Source

impl RecurrencePattern

pub fn frequency(&self) -> &RecurrenceFrequency

Defines how often the pattern repeats. This is the base unit for the recurrence schedule and works in conjunction with the Interval field to determine the exact repetition sequence.

pub fn interval(&self) -> i32

Specifies the number of frequency units between each occurrence. Must be a positive integer.

Examples: To repeat every week, set Interval=1 with WEEKLY frequency. To repeat every two months, set Interval=2 with MONTHLY frequency.

pub fn by_month(&self) -> &[i32]

Specifies which month the event should occur in (1-12, where 1=January, 12=December). Used with YEARLY frequency to schedule events in specific month.

Note: It does not accept multiple values in the same list

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .by_month.is_none().

pub fn by_month_day(&self) -> &[i32]

Specifies which day of the month the event should occur on (1-31). Used with MONTHLY or YEARLY frequency to schedule events on specific date within a month.

Examples: \[15\] for events on the 15th of each month, \[-1\] for events on the last day of month.

Note: It does not accept multiple values in the same list. If a specified day doesn't exist in a particular month (e.g., day 31 in February), the event will be skipped for that month. This field cannot be used simultaneously with ByWeekdayOccurrence as they represent different scheduling approaches (specific dates vs. relative weekday positions).

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .by_month_day.is_none().

pub fn by_weekday_occurrence(&self) -> &[i32]

Specifies which occurrence of a weekday within the month the event should occur on. Must be used with MONTHLY or YEARLY frequency.

Example: 2 corresponds to second occurrence of the weekday in the month. -1 corresponds to last occurrence of the weekday in the month

The weekday itself is specified separately in the HoursOfOperationConfig. Example: To schedule the recurring event for the 2nd Thursday of April every year, set ByWeekdayOccurrence=\[2\], Day=THURSDAY, ByMonth=\[4\], Frequency: YEARLY and INTERVAL=1.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .by_weekday_occurrence.is_none().

Source

impl RecurrencePattern

pub fn builder() -> RecurrencePatternBuilder

Creates a new builder-style object to manufacture RecurrencePattern.