#[non_exhaustive]pub struct Notification {
pub content: Option<HashMap<LocaleCode, String>>,
pub id: String,
pub arn: String,
pub priority: Option<NotificationPriority>,
pub recipients: Option<Vec<String>>,
pub last_modified_time: DateTime,
pub created_at: Option<DateTime>,
pub expires_at: Option<DateTime>,
pub last_modified_region: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Contains information about a notification, including its content, priority, recipients, and metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: Option<HashMap<LocaleCode, String>>The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
id: StringThe unique identifier for the notification.
arn: StringThe Amazon Resource Name (ARN) of the notification.
priority: Option<NotificationPriority>The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
recipients: Option<Vec<String>>A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
last_modified_time: DateTimeThe timestamp when the notification was last modified.
created_at: Option<DateTime>The timestamp when the notification was created.
expires_at: Option<DateTime>The timestamp when the notification expires and is no longer displayed to users.
last_modified_region: Option<String>The AWS Region where the notification was last modified.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
Implementations
Sourceimpl Notification
impl Notification
Sourcepub fn content(&self) -> Option<&HashMap<LocaleCode, String>>
pub fn content(&self) -> Option<&HashMap<LocaleCode, String>>
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
Sourcepub fn priority(&self) -> Option<&NotificationPriority>
pub fn priority(&self) -> Option<&NotificationPriority>
The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
Sourcepub fn recipients(&self) -> &[String]
pub fn recipients(&self) -> &[String]
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .recipients.is_none().
Sourcepub fn last_modified_time(&self) -> &DateTime
pub fn last_modified_time(&self) -> &DateTime
The timestamp when the notification was last modified.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the notification was created.
Sourcepub fn expires_at(&self) -> Option<&DateTime>
pub fn expires_at(&self) -> Option<&DateTime>
The timestamp when the notification expires and is no longer displayed to users.
Sourcepub fn last_modified_region(&self) -> Option<&str>
pub fn last_modified_region(&self) -> Option<&str>
The AWS Region where the notification was last modified.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
Sourceimpl Notification
impl Notification
Sourcepub fn builder() -> NotificationBuilder
pub fn builder() -> NotificationBuilder
Creates a new builder-style object to manufacture Notification.